---
name: "\U0001F41B Bug report"
about: Create a report to help us improve
title: "[BUG] "
labels: bug
assignees: ''

---

## 🐛 Bug Report

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See error

**Expected behavior**
A clear and concise description of what you expected to happen.

**Screenshots**
If applicable, add screenshots to help explain your problem.

**Please answer these questions to help us pinpoint the problem**
- Does the problem occur in `merlin run --local` mode, distributed mode or neither?
- If a distributed problem, which backend and queue servers are you using? How are they configured?
- On what machines/architectures are you running merlin? Is this bug on a specific machine or can you reproduce it elsewhere?

**Please run `merlin info` and paste the results here:**


**Additional context**
Add any other context about the problem here.
